@@ -113,18 +113,69 @@ int priority(int op)
 
 int last_digit(double a)
 {
-	return round(a - 10.0 * floor(a / 10.0));
+	return round_double_to_int(a - 10.0 * floor(a / 10.0));
 }
 
 int almost_integer(double a, double precision)
 {
-	if (fabs(a - round(a)) < precision * fabs(a))
+	if (fabs(a - round_double_to_int(a)) < precision * fabs(a))
 		return TRUE;
 	else 
 		return FALSE;
 }
 
-int round(double a)
+/* the name is weird on purpose; in order to prevent possible
+ * name conflicts */
+double sign_of_double(double a)
+{
+	if (a > 0.0)
+		return 1.0;
+	else if (a < 0.0)
+		return -1.0;
+	else 
+		return 0.0;
+}
+
+double max_fabs(double a, double b) 
+{
+	double fa, fb;
+	fa = fabs(a);
+	fb = fabs(b);
+	if (fa > fb)
+		return fa;
+	else 
+		return fb;
+}
+
+
+double smart_sum(double a, double b, double precision)
+{
+	double sumabs, sumsign, cutoff;
+
+	if ( fabs(a + b) < fabs(a) * precision ){
+		/* hack to have 100.1 - 100 - 0.1 == 0 */
+		return 0.0;
+	} else {
+		sumabs = fabs(a + b);
+		sumsign = sign_of_double(a + b); 
+		if (floor(log10(max_fabs(a, b))) <= ceil(log10(sumabs)))
+			return sumsign * sumabs;
+		cutoff = pow(10, ceil(log10(max_fabs(a, b)))) * precision;
+		if (cutoff < sumabs) {
+			return sumsign * cutoff * rint(sumabs / cutoff);
+		} else {
+			return 0.0;
+		}
+	}
+
+}
+
+
+/* Yes, this is one weird name. It used to be just "round", 
+ * but it conflicted with a function with the same name
+ * defined in math.h on Mac OS X. In order to prevent this and 
+ * possible future name conflicts, the present name was chosen */
+int round_double_to_int(double a)
 {
 	if (a >= 0.0)
 		return (int)(a + 0.5);
