@@ -33,7 +33,7 @@ void call_exit(void);
 /* b_buttons.c */ 
 void create_calcoo_display(int, int, int, int);
 void create_button(int, int, int, int, int, char ***, void (*)(void), char *);
-void create_invisible_button(int, void (*)(void));
+/* void create_invisible_button(int, void (*)(void)); */
 void create_toggle_button(int, int, int, int, int, char ***, void (*)(void), 
 			  char *);
 void create_copy_button(int, int, int, int, int, char ***, char *);
@@ -97,9 +97,6 @@ void call_settings (void);
 void load_settings(void);
 void save_settings(void);
 
-/* b_accel.c */
-void assign_accel(void);
-void set_accel_mode(int);
 
 
 /* main.c */
