@@ -1,7 +1,7 @@
 /*
  * Calcoo: b_info.c
  *
- * Copyright (C) 2001, 2005 Alexei Kaminski
+ * Copyright (C) 2001, 2005, 2007 Alexei Kaminski
  *
  * creates and operates the info window
  *
@@ -36,21 +36,25 @@ void call_info (void)
 {
 	static GtkWidget *info_window = NULL;
 
-	GdkPixmap *main_pixmap;
-	GdkBitmap *main_mask;
-
 	GtkWidget *info_vbox;
 	GtkWidget *info_notebook;
 	GtkWidget *button_box;
 
 	GtkWidget *about_vbox, *about_label;
 
-	GtkWidget *license_vbox, *license_clist, *license_scrollwin;
-	GtkWidget *shortcuts_vbox, *shortcuts_clist, *shortcuts_scrollwin;
-	GtkWidget *help_vbox, *help_clist, *help_scrollwin;
+	GtkWidget *license_vbox, *license_textview, *license_scrollwin;
+	GtkWidget *shortcuts_vbox, *shortcuts_scrollwin;
+	GtkListStore *shortcuts_store;
+	GtkTreeIter  shortcuts_iter;
+	GtkWidget *shortcuts_tree;
+	GtkCellRenderer *shortcuts_renderer_right_align, *shortcuts_renderer_left_align;
+	GtkTreeViewColumn *shortcuts_column;
+
+	GtkWidget *help_vbox, *help_textview, *help_scrollwin;
+	GtkTextBuffer *license_buf, *help_buf;
 
 	gint i;
-	char *tit[3];
+	char *shortcuts_header[3];
 
 	if (info_window)
 		return;
@@ -61,7 +65,7 @@ void call_info (void)
 	gtk_window_set_resizable(GTK_WINDOW(info_window),TRUE);
 	gtk_container_set_border_width(GTK_CONTAINER(info_window), 
 				       INFO_SPACING);
-	gtk_signal_connect(GTK_OBJECT(info_window), "destroy",
+	g_signal_connect(G_OBJECT(info_window), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), 
 			   &info_window);
 	g_signal_connect (G_OBJECT (info_window), 
@@ -75,15 +79,9 @@ void call_info (void)
 	gtk_widget_realize(info_window);
 	
 /* Main info window icon */
-	main_pixmap = gdk_pixmap_create_from_xpm_d ( 
-		info_window->window,
-		&main_mask,
-		&(body->style)->bg[GTK_STATE_NORMAL],
-		(gchar **) main_xpm 
-		);
 
-  	gdk_window_set_icon (info_window->window, NULL,  
-  			     main_pixmap, main_mask); 
+  	gtk_window_set_icon (GTK_WINDOW(info_window),  
+  			gdk_pixbuf_new_from_xpm_data((const char **)main_xpm));
 
 
 	info_vbox = gtk_vbox_new(FALSE, INFO_SPACING);
@@ -112,29 +110,18 @@ void call_info (void)
 				 gtk_label_new("About"));
 	
 	/* License */
-  	license_clist = gtk_clist_new(1); 
+	license_buf = gtk_text_buffer_new(NULL);
+	gtk_text_buffer_set_text(license_buf, license_text, -1);
+	license_textview = gtk_text_view_new_with_buffer(license_buf);
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(license_textview), GTK_WRAP_WORD);
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(license_textview), FALSE);
 
-  	i = 0; 
-  	while ( license_text[i] || license_text[i + 1]) { 
-		char **temp;
-		char *temp1;
-		guint row;
-		
-		temp1 = license_text[i];
-		temp = &temp1;
-		row = gtk_clist_append(GTK_CLIST(license_clist), temp);
-		gtk_clist_set_selectable(GTK_CLIST(license_clist), row, FALSE);
-		i++;
-	}
-
-	gtk_clist_columns_autosize(GTK_CLIST(license_clist));
-	gtk_clist_set_column_justification(GTK_CLIST(license_clist), 0, 
-					   GTK_JUSTIFY_LEFT);
-	
 	license_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(license_scrollwin),
 				       GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-	gtk_container_add(GTK_CONTAINER(license_scrollwin), license_clist);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(license_scrollwin),
+					    GTK_SHADOW_IN);
+	gtk_container_add(GTK_CONTAINER(license_scrollwin), license_textview);
 
 
 	license_vbox = gtk_vbox_new(FALSE, INFO_SPACING);
@@ -142,7 +129,7 @@ void call_info (void)
 				       INFO_SPACING);
   	gtk_box_pack_start(GTK_BOX(license_vbox), license_scrollwin, 
 			   TRUE, TRUE, 0); 
-  	gtk_widget_set_usize(license_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
+  	gtk_widget_set_size_request(license_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
 
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(info_notebook), 
@@ -150,50 +137,70 @@ void call_info (void)
 				 gtk_label_new("License"));
 
 	/* Shortcuts */
-	tit[0] = "Shortcuts";
-	tit[1] = " ";
-	tit[2] = "Actions";
-  	shortcuts_clist = gtk_clist_new_with_titles(3, tit); 
+
+	shortcuts_header[0] = "Shortcuts";
+	shortcuts_header[1] = " ";
+	shortcuts_header[2] = "Actions";
+	shortcuts_store = gtk_list_store_new ( 3,
+					       G_TYPE_STRING,
+					       G_TYPE_STRING,
+					       G_TYPE_STRING);
+
+	shortcuts_tree = gtk_tree_view_new_with_model(GTK_TREE_MODEL (shortcuts_store));	
+
+	shortcuts_renderer_right_align = gtk_cell_renderer_text_new();
+	gtk_object_set( GTK_OBJECT(shortcuts_renderer_right_align), 
+			"xalign", 1.0, 
+			NULL );
+
+	shortcuts_renderer_left_align = gtk_cell_renderer_text_new();
+
+	shortcuts_column = gtk_tree_view_column_new_with_attributes (shortcuts_header[0],
+								     shortcuts_renderer_right_align,
+								     "text", 0,
+								     NULL);
+	gtk_tree_view_column_set_alignment(shortcuts_column, 1.0);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (shortcuts_tree), shortcuts_column);
+	shortcuts_column = gtk_tree_view_column_new_with_attributes (shortcuts_header[1],
+								     shortcuts_renderer_right_align,
+								     "text", 1,
+								     NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (shortcuts_tree), shortcuts_column);
+	shortcuts_column = gtk_tree_view_column_new_with_attributes (shortcuts_header[2],
+								     shortcuts_renderer_left_align,
+								     "text", 2,
+								     NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (shortcuts_tree), shortcuts_column);
+
 
   	i = 0; 
   	while ( shortcuts_text[i] || shortcuts_text[i + 2]) { 
-		char *temp[3];
-		char *temp1, *temp2;
-		guint row;
-		
-		temp1 = shortcuts_text[i];
-		temp2 = shortcuts_text[i+1];
-		temp[0] = temp1;
-		temp[1] = "   ";
-		temp[2] = temp2;
-		row = gtk_clist_append(GTK_CLIST(shortcuts_clist), temp);
-		gtk_clist_set_selectable(GTK_CLIST(shortcuts_clist), row, 
-					 FALSE);
+		gtk_list_store_append (shortcuts_store, &shortcuts_iter); 
+
+		gtk_list_store_set (shortcuts_store, &shortcuts_iter,
+				    0, shortcuts_text[i],
+				    1, "   ",
+				    2, shortcuts_text[i+1],
+				    -1);
 		i++; i++;
 	}
 
-	gtk_clist_columns_autosize(GTK_CLIST(shortcuts_clist));
-	gtk_clist_set_column_resizeable(GTK_CLIST(shortcuts_clist), 0, FALSE);
-	gtk_clist_set_column_justification(GTK_CLIST(shortcuts_clist), 0, 
-					   GTK_JUSTIFY_RIGHT);
-	gtk_clist_set_column_resizeable(GTK_CLIST(shortcuts_clist), 1, FALSE);
-	gtk_clist_set_column_resizeable(GTK_CLIST(shortcuts_clist), 2, FALSE);
-	gtk_clist_set_column_justification(GTK_CLIST(shortcuts_clist), 2, 
-					   GTK_JUSTIFY_LEFT);
-	
+
+
 	shortcuts_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(
 		GTK_SCROLLED_WINDOW(shortcuts_scrollwin),
 		GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-	gtk_container_add(GTK_CONTAINER(shortcuts_scrollwin), shortcuts_clist);
-
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(shortcuts_scrollwin),
+					    GTK_SHADOW_IN);
+	gtk_container_add(GTK_CONTAINER(shortcuts_scrollwin), shortcuts_tree);
 
 	shortcuts_vbox = gtk_vbox_new(FALSE, INFO_SPACING);
 	gtk_container_set_border_width(GTK_CONTAINER(shortcuts_vbox), 
 				       INFO_SPACING);
   	gtk_box_pack_start(GTK_BOX(shortcuts_vbox), shortcuts_scrollwin, 
 			   TRUE, TRUE, 0); 
-  	gtk_widget_set_usize(shortcuts_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
+  	gtk_widget_set_size_request(shortcuts_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
 
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(info_notebook), 
@@ -201,29 +208,19 @@ void call_info (void)
 				 gtk_label_new("Shortcuts"));
 
 	/* Help */
-  	help_clist = gtk_clist_new(1); 
+	help_buf = gtk_text_buffer_new(NULL);
+	gtk_text_buffer_set_text(help_buf, help_text, -1);
+	help_textview = gtk_text_view_new_with_buffer(help_buf);
+	gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(help_textview), GTK_WRAP_WORD);
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(help_textview), FALSE);
 
-  	i = 0; 
-  	while ( help_text[i] || help_text[i + 1]) { 
-		char **temp;
-		char *temp1;
-		guint row;
-		
-		temp1 = help_text[i];
-		temp = &temp1;
-		row = gtk_clist_append(GTK_CLIST(help_clist), temp);
-		gtk_clist_set_selectable(GTK_CLIST(help_clist), row, FALSE);
-		i++;
-	}
 
-	gtk_clist_columns_autosize(GTK_CLIST(help_clist));
-	gtk_clist_set_column_justification(GTK_CLIST(help_clist), 0, 
-					   GTK_JUSTIFY_LEFT);
-	
 	help_scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(help_scrollwin),
 				       GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
-	gtk_container_add(GTK_CONTAINER(help_scrollwin), help_clist);
+	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(help_scrollwin),
+					    GTK_SHADOW_IN);
+	gtk_container_add(GTK_CONTAINER(help_scrollwin), help_textview);
 
 
 	help_vbox = gtk_vbox_new(FALSE, INFO_SPACING);
@@ -231,7 +228,7 @@ void call_info (void)
 				       INFO_SPACING);
   	gtk_box_pack_start(GTK_BOX(help_vbox), help_scrollwin, 
 			   TRUE, TRUE, 0); 
-  	gtk_widget_set_usize(help_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
+  	gtk_widget_set_size_request(help_scrollwin, -1, INFO_SCROLLWIN_HEIGHT); 
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(info_notebook), 
 				 help_vbox,
@@ -241,13 +238,13 @@ void call_info (void)
 	button_box = gtk_hbutton_box_new();
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(button_box), 
 				  GTK_BUTTONBOX_END);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(button_box), INFO_SPACING);
+	gtk_box_set_spacing(GTK_BOX(button_box), INFO_SPACING);
 	gtk_box_pack_start(GTK_BOX(info_vbox), button_box, FALSE, FALSE, 0);
 
 	close_button = gtk_button_new_with_label("Close");
-	gtk_signal_connect_object(GTK_OBJECT(close_button), "clicked",
+	g_signal_connect_swapped(G_OBJECT(close_button), "clicked",
 				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				  GTK_OBJECT(info_window));
+				  G_OBJECT(info_window));
 	gtk_box_pack_start(GTK_BOX(button_box), close_button, TRUE, TRUE, 0);
 
 	gtk_widget_show_all(info_window);
@@ -277,7 +274,7 @@ gboolean info_key_press_handler(GtkWidget* widget,
   switch (event->keyval)
     {
     case GDK_Escape:
-	    gtk_signal_emit_by_name(GTK_OBJECT(close_button),
+	    g_signal_emit_by_name(G_OBJECT(close_button),
 				    "clicked");
 	    return TRUE;
     default:
