@@ -1,7 +1,7 @@
 /*
  * Calcoo: b_layout.c
  *
- * Copyright (C) 2001,2002 Alexei Kaminski
+ * Copyright (C) 2001, 2002, 2005 Alexei Kaminski
  *
  * determines layout of the buttons
  * calls create_display()
@@ -109,14 +109,16 @@
 
 void create_widgets(void)
 {
-	char **button_xpm[MAX_BUTTON_NUMBER],
-		**digit_xpm[NUMBER_OF_DISPLAY_GLYPHS], 
-		**ldigit_xpm[NUMBER_OF_DISPLAY_GLYPHS],
-		**op_xpm[NUMBER_OF_OPERATION_DISPLAY_GLYPHS],
-		**deg_rad_xpm[NUMBER_OF_ANGLE_UNIT_GLYPHS],
-		**format_xpm[NUMBER_OF_FORMAT_GLYPHS],
-		**reg_display_label_xpm[NUMBER_OF_REG_DISPLAYS];
-	
+	char **button_xpm[MAX_BUTTON_NUMBER];
+	char **op_xpm[NUMBER_OF_OPERATION_DISPLAY_GLYPHS];
+	char **deg_rad_xpm[NUMBER_OF_ANGLE_UNIT_GLYPHS];
+	char **format_xpm[NUMBER_OF_FORMAT_GLYPHS];
+	char **reg_display_label_xpm[NUMBER_OF_REG_DISPLAYS];
+	static char **digit_xpm[NUMBER_OF_DISPLAY_GLYPHS];
+	static char **ldigit_xpm[NUMBER_OF_DISPLAY_GLYPHS];
+	/* static because the display digit widgets are created on demand,
+	 * therefore one need a static repository for their pixmaps */
+
 	int i;
 
 	create_main_window(BODY_SIZE_HORIZ, BODY_SIZE_VERT);
@@ -661,8 +663,6 @@ void create_widgets(void)
 		      button_xpm, &clicked_code_switch_to_mem1, 
 		      "Switch to memory register 1");
 
-	create_invisible_button(CODE_EXIT, &clicked_code_exit);
-
 
 	for(i = 0; i < NUMBER_OF_MEMS; i++)
 		create_display(MEM_DISPLAY_OFFSET + i,
