@@ -216,7 +216,7 @@ void create_two_option_box(GtkWidget **option1, GtkWidget **option2,
 		*last = value2;
 		*set = value2;
 	}
-	gtk_signal_connect(GTK_OBJECT (*option1), "toggled",
+	g_signal_connect(G_OBJECT (*option1), "toggled",
 			   GTK_SIGNAL_FUNC (function1), NULL);
 
 	*box = gtk_vbox_new(TRUE, 0);
@@ -246,15 +246,15 @@ void create_checkbox(GtkWidget **checkbox, char *text,
 		*last = FALSE;
 		*set = FALSE;
 	}
-	gtk_signal_connect(GTK_OBJECT (*checkbox), "toggled",
+	g_signal_connect(G_OBJECT (*checkbox), "toggled",
 			   GTK_SIGNAL_FUNC (function1), NULL);
 }
 
 void call_settings (void)
 {
 	static GtkWidget *settings_window = NULL;
-	GdkPixmap *main_pixmap;
-	GdkBitmap *main_mask;
+	//GdkPixmap *main_pixmap;
+	//GdkBitmap *main_mask;
 
 	GtkWidget *close_button;
 
@@ -279,13 +279,14 @@ void call_settings (void)
 	gtk_window_set_title(GTK_WINDOW(settings_window), "Calcoo settings");
 	gtk_window_set_resizable(GTK_WINDOW(settings_window),FALSE);
 	gtk_container_set_border_width(GTK_CONTAINER(settings_window), 0);
-	gtk_signal_connect(GTK_OBJECT(settings_window), "destroy",
+	g_signal_connect(G_OBJECT(settings_window), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), 
 			   &settings_window);
 
 	gtk_widget_realize(settings_window);
 	
 /* Main settings window icon */
+/*
 	main_pixmap = gdk_pixmap_create_from_xpm_d ( 
 		settings_window->window,
 		&main_mask,
@@ -294,7 +295,10 @@ void call_settings (void)
 		);
 
   	gdk_window_set_icon (settings_window->window, NULL,  
-  			     main_pixmap, main_mask); 
+  			     main_pixmap, main_mask);
+*/
+  	gtk_window_set_icon (GTK_WINDOW(settings_window),  
+  			gdk_pixbuf_new_from_xpm_data((const char **)main_xpm));
 
 /* Settings */
 	create_two_option_box(&rpn_radio1, &rpn_radio2,
@@ -345,14 +349,14 @@ void call_settings (void)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(round_check), 
 					     FALSE);
 	}
-	gtk_signal_connect(GTK_OBJECT (round_check), "toggled",
+	g_signal_connect(G_OBJECT (round_check), "toggled",
 			   GTK_SIGNAL_FUNC (pressed_round), NULL);
 
 	round_adjustment = (GtkAdjustment *)gtk_adjustment_new(abs(round_last),
 							       1, INPUT_LENGTH,
 							       1, 1, 1);
 	round_spinbox = gtk_spin_button_new (round_adjustment, 1, 0);
-	gtk_signal_connect(GTK_OBJECT (round_adjustment), "value-changed",
+	g_signal_connect(G_OBJECT (round_adjustment), "value-changed",
 			   GTK_SIGNAL_FUNC (round_value_changed), NULL);
 
 	round_label2 = gtk_label_new("digits");
@@ -388,18 +392,18 @@ void call_settings (void)
 
 /* Buttons */
 	apply_button = gtk_button_new_with_label("Apply");
-	gtk_signal_connect(GTK_OBJECT (apply_button), "clicked",
+	g_signal_connect(G_OBJECT (apply_button), "clicked",
 			   GTK_SIGNAL_FUNC (apply_new_settings), NULL);
 
 	close_button = gtk_button_new_with_label("Close");
-	gtk_signal_connect_object(GTK_OBJECT(close_button), "clicked",
+	g_signal_connect_swapped(G_OBJECT(close_button), "clicked",
 				  GTK_SIGNAL_FUNC(gtk_widget_destroy),
-				  GTK_OBJECT(settings_window));
+				  G_OBJECT(settings_window));
 
 	settings_button_box = gtk_hbutton_box_new();
 	gtk_button_box_set_layout(GTK_BUTTON_BOX(settings_button_box), 
 				  GTK_BUTTONBOX_SPREAD);
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(settings_button_box), 
+	gtk_box_set_spacing(GTK_BOX(settings_button_box), 
 				   INFO_SPACING);
 	gtk_box_pack_start(GTK_BOX(settings_button_box), apply_button, 
 			   FALSE, FALSE, 0);
