@@ -19,7 +19,6 @@ void call_sign(void);
 void call_exp_sign(void);
 void call_import_paste(double);
 void call_change_display_format(void);
-void call_change_angle_measure(void);
 
 /* c_mem.c */
 void call_mem_op(int);
@@ -31,8 +30,8 @@ void call_unary_op(int);
 void call_eq(void);
 void call_enter(void); 
 void call_exch_xy(void);
-void call_exch_xz(void);
-void call_exch_xt(void);
+void call_stack_up(void);
+void call_stack_down(void);
 void call_left_paren(void);
 void call_right_paren(void);
 void push_stack(void);
@@ -47,8 +46,15 @@ void call_set_rpn_mode(int);
 int  call_get_rpn_mode(void);
 void call_set_enter_mode(int);
 int  call_get_enter_mode(void);
+void call_set_rounding_mode(int);
+int  call_get_rounding_mode(void);
+void call_set_trunc_zeros_mode(int);
+int  call_get_trunc_zeros_mode(void);
 void call_set_stack_mode(int);
 int call_get_stack_mode(void);
+void call_change_angle_units(void);
+int call_get_angle_units(void);
+void call_set_angle_units(int);
 void aftermath(void);
 /* c_output.c */
 void cpu_to_output(void);
