@@ -1,7 +1,7 @@
 /*
  * Calcoo: c_main.c
  *
- * Copyright (C) 2001, 2002 Alexei Kaminski
+ * Copyright (C) 2001, 2002, 2003 Alexei Kaminski
  *
  * creates and initializes cpu
  *
@@ -11,6 +11,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
+#include <float.h>
 
 #include "codes.h"
 #include "const.h"
@@ -71,11 +72,20 @@ void init_cpu(void)
 		* weird stuff displayed in the operation displays in the 
 		* algebraic mode from after initialization until the next
 		* call to cpu_to_output */
-	cpu->precision = pow(10, -(INPUT_LENGTH - 1));	/* slightly 
-		* underestimated precision 
-		* it is going to be used in evaluation of
-		* trigonometric functions to get sin PI == 0 
-		* rather than 10^-17 */
+
+	if (MAXIMIZE_PRECISION)
+		cpu->precision = pow(10, -floor(fabs(log10(DBL_EPSILON))) + 1);
+	        /* "+1" is just in case, to underestimate precision;
+		 * as for -floor(fabs()), it is just me being paranoid, 
+		 * since I am not sure wether the behavior of floor()
+		 * of a negative number is universal */
+	else
+		cpu->precision = pow(10, -INPUT_LENGTH - 1); 
+        /* it is going to be used in evaluation of
+	 * trigonometric functions to get sin PI == 0 
+	 * rather than 10^-17 and also in subtraction/addition 
+	 * to have 100.1 - 100 - 0.1 == 0 rather than 1e-15 */
+
 	cpu_to_output();
 	init_undo_stack();
   	refresh_body(); 
