@@ -69,14 +69,14 @@ void create_fg_pixmap(GtkWidget **pixmap_widget, char **pixmap_xpm)
 	if (CONVERT_ICONS_TO_FOREGROUND_COLOR)
 		/* imposing the transparency mask of the original pixmap
 		 * onto the foreground rectangle */
-		*pixmap_widget = gtk_pixmap_new(all_black, mask);
+		*pixmap_widget = gtk_image_new_from_pixmap(all_black, mask);
 	else
-		*pixmap_widget = gtk_pixmap_new(pixmap, mask);
+		*pixmap_widget = gtk_image_new_from_pixmap(pixmap, mask);
 
 	free(black_bits);
-	gdk_pixmap_unref(pixmap);
-	gdk_pixmap_unref(all_black);
-	gdk_bitmap_unref(mask);
+	g_object_unref(pixmap);
+	g_object_unref(all_black);
+	g_object_unref(mask);
 }
 
 void create_n_put_pixmap(GtkWidget **pixmap_widget, int x, int y, 
