@@ -10,9 +10,11 @@
 
 void create_n_put_pixmap(GtkWidget **, int, int, char **);
 void create_fg_pixmap(GtkWidget **, char **);
-void own_selection(GtkWidget *);
-void set_selection(GtkWidget * , GtkSelectionData *, guint, guint, gpointer);
-void request_selection(GtkWidget *);
+void request_selection(GtkWidget *, gpointer);
 void get_selection(GtkWidget *, GtkSelectionData *, gpointer);
 
+void own_selection( GtkWidget *, gint * );
+gboolean selection_clear( GtkWidget *, GdkEventSelection *, gint *);
+void set_selection(GtkWidget * , GtkSelectionData *, guint, guint, gpointer);
+
 #endif /* GTKAUX_HEADERS_H */
